DeviceMotionData class

An object that contains all information about the airpods data.

Constructors

DeviceMotionData(Attitude attitude, Gravity gravity, RotationRate rotationRate, UserAcceleration userAcceleration, CalibratedMagneticField calibratedMagneticField, num heading)
const
DeviceMotionData.fromJson(Map<String, dynamic> json)
Creates a new DeviceMotionData from a JSON
factory

Properties

attitude → Attitude
final
calibratedMagneticField → CalibratedMagneticField
final
gravity → Gravity
final
hashCode → int
The hash code for this object.
no setterinherited
heading → num
final
props → List<Object?>
Used for comparison of device motion data objects.
no setter
rotationRate → RotationRate
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
userAcceleration → UserAcceleration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Creates a JSON from an existing DeviceMotionData
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited